@@ -18,22 +18,22 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #include "typesystem.h"
-#include "../indexedstring.h"
-#include "../repositories/typerepository.h"
+#include "typerepository.h"
 #include "typesystemdata.h"
 #include "typeregister.h"
-
 #include "integraltype.h"
 #include "structuretype.h"
 
+#include <serialization/indexedstring.h>
+
 namespace KDevelop
 {
 
 AbstractTypeData::AbstractTypeData()
-  : m_modifiers(AbstractType::NoModifiers)
-  , inRepository(false), refCount(0)
+  : refCount(0)
+  , m_modifiers(AbstractType::NoModifiers)
+  , inRepository(false)
 {
   initializeAppendedLists(true);
 }
@@ -52,8 +52,9 @@ unsigned int AbstractTypeData::hash() const {
 }
 
 AbstractTypeData::AbstractTypeData( const AbstractTypeData& rhs )
-  : m_modifiers(rhs.m_modifiers)
-  , inRepository(false), refCount(0)
+  : refCount(0)
+  , m_modifiers(rhs.m_modifiers)
+  , inRepository(false)
 {
   initializeAppendedLists(!rhs.m_dynamic); //This type will be dynamic exactly if the copied one is not.
   typeClassId = rhs.typeClassId;
@@ -209,12 +210,12 @@ TypeVisitor::~TypeVisitor()
 }
 
 TypePtr< KDevelop::AbstractType > TypeExchanger::exchange(const TypePtr< KDevelop::AbstractType >& type) {
-  const_cast<AbstractType*>(type.unsafeData())->exchangeTypes(this);
+  const_cast<AbstractType*>(type.data())->exchangeTypes(this);
   return type;
 }
 
 TypePtr< KDevelop::AbstractType > SimpleTypeExchanger::exchange(const TypePtr< KDevelop::AbstractType >& type) {
-  if(type && type->equals(m_replace.unsafeData()))
+  if(type && type->equals(m_replace.data()))
     return m_replaceWith;
   else
     return TypeExchanger::exchange(type);
@@ -225,5 +226,3 @@ SimpleTypeExchanger::SimpleTypeExchanger(TypePtr< KDevelop::AbstractType > repla
 
 
 }
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
