@@ -43,6 +43,7 @@
 #include <KTextEditor/Document>
 #include <KTextEditor/TextHintInterface>
 #include <KTextEditor/View>
+#include <KTextEditor/ConfigInterface>
 
 #include <interfaces/icore.h>
 #include <interfaces/idocumentcontroller.h>
@@ -55,6 +56,8 @@
 #include <language/interfaces/ilanguagesupport.h>
 #include <language/interfaces/iquickopen.h>
 
+#include <language/highlighting/colorcache.h>
+
 #include <language/duchain/duchain.h>
 #include <language/duchain/ducontext.h>
 #include <language/duchain/declaration.h>
@@ -294,6 +297,7 @@ ContextBrowserPlugin::ContextBrowserPlugin(QObject *parent, const QVariantList&)
 
   connect( core()->documentController(), &IDocumentController::textDocumentCreated, this, &ContextBrowserPlugin::textDocumentCreated );
   connect( DUChain::self(), &DUChain::updateReady, this, &ContextBrowserPlugin::updateReady);
+  connect( ColorCache::self(), &ColorCache::colorsGotChanged, this, &ContextBrowserPlugin::colorSetupChanged );
 
   connect( DUChain::self(), &DUChain::declarationSelected,
            this, &ContextBrowserPlugin::declarationSelectedInUI );
@@ -618,34 +622,26 @@ void ContextBrowserPlugin::clearMouseHover() {
   m_mouseHoverDocument.clear();
 }
 
-Attribute::Ptr highlightedUseAttribute() {
-  static Attribute::Ptr standardAttribute = Attribute::Ptr();
-  if( !standardAttribute ) {
-    standardAttribute= Attribute::Ptr( new Attribute() );
-    standardAttribute->setBackgroundFillWhitespace(true);
+Attribute::Ptr ContextBrowserPlugin::highlightedUseAttribute(KTextEditor::View* view) const {
+  if( !m_highlightAttribute ) {
+    m_highlightAttribute = Attribute::Ptr( new Attribute() );
+    m_highlightAttribute->setDefaultStyle(KTextEditor::dsNormal);
+    m_highlightAttribute->setForeground(m_highlightAttribute->selectedForeground());
+    m_highlightAttribute->setBackgroundFillWhitespace(true);
 
-    // mixing (255, 255, 0, 100) with white yields this:
-    standardAttribute->setBackground(QColor(251, 250, 150));
-
-    // force a foreground color to overwrite default Kate highlighting, i.e. of Q_OBJECT or similar
-    // foreground color could change, hence apply it everytime
-    standardAttribute->setForeground(QColor(0, 0, 0, 255)); //Don't use alpha here, as kate uses the alpha only to blend with the document background color
+    auto iface = qobject_cast<KTextEditor::ConfigInterface*>(view);
+    auto background = iface->configValue(QStringLiteral("search-highlight-color")).value<QColor>();
+    m_highlightAttribute->setBackground(background);
   }
-  return standardAttribute;
+  return m_highlightAttribute;
 }
 
-Attribute::Ptr highlightedSpecialObjectAttribute() {
-  static Attribute::Ptr standardAttribute = Attribute::Ptr();
-  if( !standardAttribute ) {
-    standardAttribute = Attribute::Ptr( new Attribute() );
-    standardAttribute->setBackgroundFillWhitespace(true);
-    // mixing (90, 255, 0, 100) with white yields this:
-    standardAttribute->setBackground(QColor(190, 255, 155));
-    // force a foreground color to overwrite default Kate highlighting, i.e. of Q_OBJECT or similar
-    // foreground color could change, hence apply it everytime
-    standardAttribute->setForeground(QColor(0, 0, 0, 255)); //Don't use alpha here, as kate uses the alpha only to blend with the document background color
-  }
-  return standardAttribute;
+void ContextBrowserPlugin::colorSetupChanged() {
+  m_highlightAttribute = Attribute::Ptr();
+}
+
+Attribute::Ptr ContextBrowserPlugin::highlightedSpecialObjectAttribute(KTextEditor::View* view) const {
+  return highlightedUseAttribute(view);
 }
 
 void ContextBrowserPlugin::addHighlight( View* view, KDevelop::Declaration* decl ) {
@@ -660,7 +656,7 @@ void ContextBrowserPlugin::addHighlight( View* view, KDevelop::Declaration* decl
 
   // Highlight the declaration
   highlights.highlights << decl->createRangeMoving();
-  highlights.highlights.back()->setAttribute(highlightedUseAttribute());
+  highlights.highlights.back()->setAttribute(highlightedUseAttribute(view));
   highlights.highlights.back()->setZDepth(highlightingZDepth);
 
   // Highlight uses
@@ -671,7 +667,7 @@ void ContextBrowserPlugin::addHighlight( View* view, KDevelop::Declaration* decl
       for(QList< KTextEditor::Range >::const_iterator useIt = (*fileIt).constBegin(); useIt != (*fileIt).constEnd(); ++useIt)
       {
         highlights.highlights << PersistentMovingRange::Ptr(new PersistentMovingRange(*useIt, fileIt.key()));
-        highlights.highlights.back()->setAttribute(highlightedUseAttribute());
+        highlights.highlights.back()->setAttribute(highlightedUseAttribute(view));
         highlights.highlights.back()->setZDepth(highlightingZDepth);
       }
     }
@@ -680,7 +676,7 @@ void ContextBrowserPlugin::addHighlight( View* view, KDevelop::Declaration* decl
   if( FunctionDefinition* def = FunctionDefinition::definition(decl) )
   {
     highlights.highlights << def->createRangeMoving();
-    highlights.highlights.back()->setAttribute(highlightedUseAttribute());
+    highlights.highlights.back()->setAttribute(highlightedUseAttribute(view));
     highlights.highlights.back()->setZDepth(highlightingZDepth);
   }
 }
@@ -771,7 +767,7 @@ void ContextBrowserPlugin::updateForView(View* view)
       if(allowHighlight)
       {
         highlights.highlights << PersistentMovingRange::Ptr(new PersistentMovingRange(specialRange, IndexedString(url)));
-        highlights.highlights.back()->setAttribute(highlightedSpecialObjectAttribute());
+        highlights.highlights.back()->setAttribute(highlightedSpecialObjectAttribute(view));
         highlights.highlights.back()->setZDepth(highlightingZDepth);
       }
       if(updateBrowserView)
