@@ -57,7 +57,7 @@ using namespace KDevelop;
 
 QIcon NativeAppConfigPage::icon() const
 {
-    return QIcon::fromTheme("system-run");
+    return QIcon::fromTheme(QStringLiteral("system-run"));
 }
 
 static KDevelop::ProjectBaseItem* itemForPath(const QStringList& path, KDevelop::ProjectModel* model)
@@ -79,7 +79,7 @@ void NativeAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelo
     }else{
         KDevelop::IProjectController* pc = KDevelop::ICore::self()->projectController();
         if( pc ){
-            executablePath->setUrl( pc->projects().count() ? pc->projects().first()->path().toUrl() : QUrl() );
+            executablePath->setUrl( pc->projects().isEmpty() ? QUrl() : pc->projects().at(0)->path().toUrl() );
         }
     }
     targetDependency->setSuggestion(project);
@@ -124,11 +124,11 @@ NativeAppConfigPage::NativeAppConfigPage( QWidget* parent )
     dependencyAction->setItemData(2, "Install" );
     dependencyAction->setItemData(3, "SudoInstall" );
 
-    addDependency->setIcon( QIcon::fromTheme("list-add") );
-    removeDependency->setIcon( QIcon::fromTheme("list-remove") );
-    moveDepUp->setIcon( QIcon::fromTheme("go-up") );
-    moveDepDown->setIcon( QIcon::fromTheme("go-down") );
-    browseProject->setIcon(QIcon::fromTheme("folder-document"));
+    addDependency->setIcon( QIcon::fromTheme(QStringLiteral("list-add")) );
+    removeDependency->setIcon( QIcon::fromTheme(QStringLiteral("list-remove")) );
+    moveDepUp->setIcon( QIcon::fromTheme(QStringLiteral("go-up")) );
+    moveDepDown->setIcon( QIcon::fromTheme(QStringLiteral("go-down")) );
+    browseProject->setIcon(QIcon::fromTheme(QStringLiteral("folder-document")));
 
     //Set workingdirectory widget to ask for directories rather than files
     workingDirectory->setMode(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly);
@@ -175,9 +175,9 @@ void NativeAppConfigPage::depEdited( const QString& str )
 
 void NativeAppConfigPage::activateDeps( int idx )
 {
-    browseProject->setEnabled( dependencyAction->itemData( idx ).toString() != "Nothing" );
-    dependencies->setEnabled( dependencyAction->itemData( idx ).toString() != "Nothing" );
-    targetDependency->setEnabled( dependencyAction->itemData( idx ).toString() != "Nothing" );
+    browseProject->setEnabled( dependencyAction->itemData( idx ).toString() != QLatin1String("Nothing") );
+    dependencies->setEnabled( dependencyAction->itemData( idx ).toString() != QLatin1String("Nothing") );
+    targetDependency->setEnabled( dependencyAction->itemData( idx ).toString() != QLatin1String("Nothing") );
 }
 
 void NativeAppConfigPage::checkActions( const QItemSelection& selected, const QItemSelection& unselected )
@@ -239,7 +239,7 @@ void NativeAppConfigPage::addDep()
 
     QListWidgetItem* item = new QListWidgetItem(icon, targetDependency->text(), dependencies);
     item->setData( Qt::UserRole, targetDependency->itemPath() );
-    targetDependency->setText("");
+    targetDependency->setText(QLatin1String(""));
     addDependency->setEnabled( false );
     dependencies->selectionModel()->clearSelection();
     item->setSelected(true);
@@ -298,12 +298,12 @@ QList< KDevelop::LaunchConfigurationPageFactory* > NativeAppLauncher::configPage
 
 QString NativeAppLauncher::description() const
 {
-    return "Executes Native Applications";
+    return QStringLiteral("Executes Native Applications");
 }
 
 QString NativeAppLauncher::id()
 {
-    return "nativeAppLauncher";
+    return QStringLiteral("nativeAppLauncher");
 }
 
 QString NativeAppLauncher::name() const
@@ -322,9 +322,9 @@ KJob* NativeAppLauncher::start(const QString& launchMode, KDevelop::ILaunchConfi
     {
         return 0;
     }
-    if( launchMode == "execute" )
+    if( launchMode == QLatin1String("execute") )
     {
-        IExecutePlugin* iface = KDevelop::ICore::self()->pluginController()->pluginForExtension("org.kdevelop.IExecutePlugin", "kdevexecute")->extension<IExecutePlugin>();
+        IExecutePlugin* iface = KDevelop::ICore::self()->pluginController()->pluginForExtension(QStringLiteral("org.kdevelop.IExecutePlugin"), QStringLiteral("kdevexecute"))->extension<IExecutePlugin>();
         Q_ASSERT(iface);
         KJob* depjob = iface->dependencyJob( cfg );
         QList<KJob*> l;
@@ -342,7 +342,7 @@ KJob* NativeAppLauncher::start(const QString& launchMode, KDevelop::ILaunchConfi
 
 QStringList NativeAppLauncher::supportedModes() const
 {
-    return QStringList() << "execute";
+    return QStringList() << QStringLiteral("execute");
 }
 
 KDevelop::LaunchConfigurationPage* NativeAppPageFactory::createWidget(QWidget* parent)
@@ -383,7 +383,7 @@ QString NativeAppConfigType::id() const
 
 QIcon NativeAppConfigType::icon() const
 {
-    return QIcon::fromTheme("application-x-executable");
+    return QIcon::fromTheme(QStringLiteral("application-x-executable"));
 }
 
 bool NativeAppConfigType::canLaunch ( KDevelop::ProjectBaseItem* item ) const
@@ -451,7 +451,7 @@ QMenu* NativeAppConfigType::launcherSuggestions()
         if(project->projectFileManager()->features() & KDevelop::IProjectFileManager::Targets) {
             QList<KDevelop::ProjectTargetItem*> targets=targetsInFolder(project->projectItem());
             QHash<KDevelop::ProjectBaseItem*, QList<QAction*> > targetsContainer;
-            QMenu* projectMenu = ret->addMenu(QIcon::fromTheme("project-development"), project->name());
+            QMenu* projectMenu = ret->addMenu(QIcon::fromTheme(QStringLiteral("project-development")), project->name());
             foreach(KDevelop::ProjectTargetItem* target, targets) {
                 if(target->executable()) {
                     QStringList path = model->pathFromIndex(target->index());
@@ -460,8 +460,8 @@ QMenu* NativeAppConfigType::launcherSuggestions()
                         act->setData(KDevelop::joinWithEscaping(path, '/','\\'));
                         act->setProperty("name", target->text());
                         path.removeFirst();
-                        act->setText(path.join("/"));
-                        act->setIcon(QIcon::fromTheme("system-run"));
+                        act->setText(path.join(QStringLiteral("/")));
+                        act->setIcon(QIcon::fromTheme(QStringLiteral("system-run")));
                         connect(act, &QAction::triggered, this, &NativeAppConfigType::suggestionTriggered);
                         targetsContainer[target->parent()].append(act);
                     }
@@ -480,7 +480,7 @@ QMenu* NativeAppConfigType::launcherSuggestions()
                     }
                     QStringList path = model->pathFromIndex(folder->index());
                     path.removeFirst();
-                    QMenu* submenu = new QMenu(path.join("/"));
+                    QMenu* submenu = new QMenu(path.join(QStringLiteral("/")));
                     std::sort(actions.begin(), actions.end(), actionLess);
                     submenu->addActions(actions);
                     submenus += submenu;
