@@ -26,7 +26,6 @@
 #include <language/duchain/problem.h>
 #include <qpointer.h>
 #include <ktexteditor/movingrange.h>
-#include <KTextEditor/TextHintInterface>
 #include <interfaces/iproblem.h>
 
 class ProblemHighlighter : public QObject
@@ -39,7 +38,6 @@ public:
     void setProblems(const QVector<KDevelop::IProblem::Ptr>& problems);
 
 private slots:
-    void viewCreated(KTextEditor::Document*, KTextEditor::View*);
     void aboutToRemoveText(const KTextEditor::Range& range);
     void clearProblems();
 
@@ -49,22 +47,8 @@ private:
     QVector<KDevelop::IProblem::Ptr> m_problems;
     QMap<KTextEditor::MovingRange*, KDevelop::IProblem::Ptr> m_problemsForRanges;
 
-    friend class ProblemTextHintProvider;
-
 public slots:
     void settingsChanged();
 };
 
-class ProblemTextHintProvider : public KTextEditor::TextHintProvider
-{
-public:
-    explicit ProblemTextHintProvider(ProblemHighlighter* highlighter);
-
-    QString textHint(KTextEditor::View* view, const KTextEditor::Cursor& position) override;
-
-private:
-    ProblemHighlighter* m_highlighter;
-    KTextEditor::Range m_currentHintRange;
-};
-
 #endif // KDEVPLATFORM_PLUGIN_PROBLEM_HIGHLIGHT_H
