@@ -31,7 +31,7 @@ static QString completionLevelToString(ICompletionSettings::CompletionLevel l)
         return QString();
     }
 
-    const static QString levels[ICompletionSettings::LAST_LEVEL] = {"Minimal", "MinimalWhenAutomatic", "AlwaysFull"};
+    const static QString levels[ICompletionSettings::LAST_LEVEL] = {QStringLiteral("Minimal"), QStringLiteral("MinimalWhenAutomatic"), QStringLiteral("AlwaysFull")};
     return levels[l];
 }
 
@@ -103,6 +103,6 @@ CompletionSettings::CompletionSettings()
     : m_level(MinimalWhenAutomatic), m_automatic(true),
       m_highlightSemanticProblems(true), m_highlightProblematicLines(false), m_showMultiLineInformation(false),
       m_boldDeclarations(true), m_localColorizationLevel(170), m_globalColorizationLevel(255),
-      m_minFilesForSimplifiedParsing(100000), m_todoMarkerWords("TODO FIXME"),
+      m_minFilesForSimplifiedParsing(100000), m_todoMarkerWords(QStringLiteral("TODO FIXME")),
       m_languageGroup(KSharedConfig::openConfig(), "Language Support"){}
 }
