@@ -31,7 +31,7 @@ TestProject::TestProject(const Path& path, QObject* parent)
 , m_root(0)
 , m_projectConfiguration(KSharedConfig::openConfig())
 {
-    m_path = path.isValid() ? path : Path("/tmp/kdev-testproject/");
+    m_path = path.isValid() ? path : Path(QStringLiteral("/tmp/kdev-testproject/"));
     m_root = new ProjectFolderItem(this, m_path);
     ICore::self()->projectController()->projectModel()->appendRow( m_root );
 }
@@ -85,14 +85,14 @@ bool TestProject::inProject(const IndexedString& path) const
     return m_path.isParentOf(Path(path.str()));
 }
 
-void findFileItems(ProjectBaseItem* root, QList<ProjectFileItem*>& items)
+void findFileItems(ProjectBaseItem* root, QList<ProjectFileItem*>& items, const Path& path = {})
 {
     foreach(ProjectBaseItem* item, root->children()) {
-        if (item->file()) {
+        if (item->file() && (path.isEmpty() || item->path() == path)) {
             items << item->file();
         }
         if (item->rowCount()) {
-            findFileItems(item, items);
+            findFileItems(item, items, path);
         }
     }
 }
@@ -104,6 +104,13 @@ QList< ProjectFileItem* > TestProject::files() const
     return ret;
 }
 
+QList<ProjectFileItem*> TestProject::filesForPath(const IndexedString& path) const
+{
+    QList<ProjectFileItem*> ret;
+    findFileItems(m_root, ret, Path(path.toUrl()));
+    return ret;
+}
+
 void TestProject::addToFileSet(ProjectFileItem* file)
 {
     if (!m_fileSet.contains(file->indexedPath())) {
@@ -119,36 +126,6 @@ void TestProject::removeFromFileSet(ProjectFileItem* file)
     }
 }
 
-void TestProjectController::addProject(IProject* p)
-{
-    emit projectAboutToBeOpened(p);
-    p->setParent(this);
-    m_projects << p;
-    emit projectOpened(p);
-}
-
-void TestProjectController::clearProjects()
-{
-    foreach(IProject* p, m_projects) {
-        closeProject(p);
-    }
-}
-
-void TestProjectController::closeProject(IProject* p)
-{
-    emit projectClosing(p);
-    delete p;
-    m_projects.removeOne(p);
-    emit projectClosed(p);
-}
-
-void KDevelop::TestProjectController::takeProject(KDevelop::IProject* p)
-{
-    emit projectClosing(p);
-    m_projects.removeOne(p);
-    emit projectClosed(p);
-}
-
 void TestProjectController::initialize()
 {
 }
